@@ -1,9 +1,11 @@
 from .client import WorkflowClient, SnippetClient
 from .models import Result, Snippet
+from .errors import WorkflowError
 
 __all__ = [
     "WorkflowClient",
     "Result",
     "SnippetClient",
     "Snippet",
+    "WorkflowError",
 ]
