@@ -3,7 +3,9 @@ class WorkflowError(Exception):
 
     title: str
     subtitle: str
+    arg: str
 
-    def __init__(self, title: str, subtitle: str):
+    def __init__(self, title: str, subtitle: str, arg: str = ""):
         self.title = title
         self.subtitle = subtitle
+        self.arg = arg
